@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::CopySubjectButton;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
@@ -44,7 +44,7 @@ Add this line:
 
 =head1 AUTHOR
 
-Averkios Averkiadis E<lt>aaverkios at outlook dot comE<gt>
+Averkios
 
 =for html <p>All bugs should be reported via email to <a
 href="mailto:bug-RT-Extension-CopySubjectButton@rt.cpan.org">bug-RT-Extension-CopySubjectButton@rt.cpan.org</a>
@@ -59,7 +59,7 @@ href="http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-CopySubjectB
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2023 by Averkios Averkiadis
+This software is Copyright (c) 2023 by Averkios
 
 This is free software, licensed under:
 
